#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# @Time : 2021/10/15 4:42 下午 
# @Author : A Big Boby
# @File : __init__.py.py 
# @Software: PyCharm

from __future__ import absolute_import
from tpypi.oh import *

name = "Oh Pig"